@@ -312,8 +312,6 @@ class ldap extends DS {
 		if (DEBUG_ENABLED && (($fargs=func_get_args())||$fargs='NOARGS'))
 			debug_log('Entered (%%)',17,0,__FILE__,__LINE__,__METHOD__,$fargs);
 
-		$size_limit = 500;
-		$time_limit = 0;
 		$attrs_only = 0;
 
 		# Defaults
@@ -335,7 +333,9 @@ class ldap extends DS {
 		if (! isset($query['scope']))
 			$query['scope'] = 'sub';
 		if (! isset($query['size_limit']))
-			$query['size_limit'] = $size_limit;
+			$query['size_limit'] = 0;
+		if (! isset($query['time_limit']))
+			$query['time_limit'] = 0;
 
 		if ($query['scope'] == 'base' && ! isset($query['baseok']))
 			system_message(array(
@@ -362,16 +362,16 @@ class ldap extends DS {
 
 		switch ($query['scope']) {
 			case 'base':
-				$search = @ldap_read($resource,$query['base'],$query['filter'],$query['attrs'],$attrs_only,$query['size_limit'],$time_limit,$query['deref']);
+				$search = @ldap_read($resource,$query['base'],$query['filter'],$query['attrs'],$attrs_only,$query['size_limit'],$query['time_limit'],$query['deref']);
 				break;
 
 			case 'one':
-				$search = @ldap_list($resource,$query['base'],$query['filter'],$query['attrs'],$attrs_only,$query['size_limit'],$time_limit,$query['deref']);
+				$search = @ldap_list($resource,$query['base'],$query['filter'],$query['attrs'],$attrs_only,$query['size_limit'],$query['time_limit'],$query['deref']);
 				break;
 
 			case 'sub':
 			default:
-				$search = @ldap_search($resource,$query['base'],$query['filter'],$query['attrs'],$attrs_only,$query['size_limit'],$time_limit,$query['deref']);
+				$search = @ldap_search($resource,$query['base'],$query['filter'],$query['attrs'],$attrs_only,$query['size_limit'],$query['time_limit'],$query['deref']);
 				break;
 		}
 
@@ -477,6 +477,7 @@ class ldap extends DS {
 			$this->getLoginClass() ? sprintf('(objectclass=%s)',join(')(objectclass=',$this->getLoginClass())) : '');
 		$query['attrs'] = array('dn');
 
+		$result = array();
 		foreach ($this->getLoginBaseDN() as $base) {
 			$query['base'] = $base;
 			$result = $this->query($query,$method);
@@ -605,17 +606,6 @@ class ldap extends DS {
 
 		static $CACHE = array();
 
-		switch (strtolower($this->getValue('sasl','mech'))) {
-			case 'gssapi':
-				if (isset($_ENV['REDIRECT_KRB5CCNAME']))
-					putenv(sprintf('KRB5CCNAME={%s}',$_ENV['REDIRECT_KRB5CCNAME']));
-
-				break;
-
-			default:
-				error(sprintf('%s (%s) has NOT been tested, please let us know if it works and which version of PHP you are using.',__METHOD__,$this->getValue('sasl','mech')),'info');
-		}
-
 		if (! $this->getValue('server','sasl') || ! function_exists('ldap_start_tls'))
 			return false;
 
@@ -624,9 +614,11 @@ class ldap extends DS {
 			$CACHE['login_pass'] = is_null($this->getPassword($method)) ? $this->getPassword('user') : $this->getPassword($method);
 		}
 
+		$mech = strtolower($this->getValue('sasl','mech'));
+
 		# Do we need to rewrite authz_id?
 		if (! isset($CACHE['authz_id']))
-			if (! trim($this->getValue('sasl','authz_id'))) {
+			if (! trim($this->getValue('sasl','authz_id')) && $mech != 'gssapi') {
 
 			if (DEBUG_ENABLED)
 				debug_log('Rewriting bind DN [%s] -> authz_id with regex [%s] and replacement [%s].',9,0,__FILE__,__LINE__,__METHOD__,
@@ -658,7 +650,7 @@ class ldap extends DS {
 		return @ldap_sasl_bind($resource,$CACHE['login_dn'],$CACHE['login_pass'],
 			$this->getValue('sasl','mech'),
 			$this->getValue('sasl','realm'),
-			$CACH['authz_id'],
+			$CACHE['authz_id'],
 			$this->getValue('sasl','props'));
 	}
 
